@@ -93,7 +93,7 @@ def setup():
     if move_old_config() is True:
         return
     conf = {'url': 'https://api.dotcloud.com/'}
-    apikey = raw_input('Enter your api key (You can find it at http://www.dotcloud.com/account/settings): ')
+    apikey = raw_input('Enter your api key (You can find it at http://www.dotcloud.com/accounts/settings): ')
     if not re.match('\w{20}:\w{40}', apikey):
         die('Not a valid api key.')
     conf['apikey'] = apikey
@@ -101,3 +101,5 @@ def setup():
         json.dump(conf, f, indent=4)
         if not is_windows():
             os.fchmod(f.fileno(), 0600)
+    if os.path.exists(CONFIG_KEY):
+        os.remove(CONFIG_KEY)
